// Copyright 2023 schukai GmbH
// SPDX-License-Identifier: AGPL-3.0

package commands

import (
	"github.com/jessevdk/go-flags"
	"gitlab.schukai.com/oss/utilities/documentation-manager/document"
	"gitlab.schukai.com/oss/utilities/documentation-manager/environment"
	"gitlab.schukai.com/oss/utilities/documentation-manager/translations"
)

const documentHTMLSymbol = "document-html"

func init() {

	h := environment.Handler{
		Init:    initDocumentHTML,
		Execute: runDocumentHTML,
	}

	environment.Handlers.Executor[documentHTMLSymbol] = h

}

type DocumentHTMLDefinition struct {
	SinglePage bool `long:"single-page" short:"s"`

	HTMLTemplate     string `long:"html-template" short:"h"`
	MarkdownTemplate string `long:"markdown-template" short:"m"`

	OutputPath string `long:"output" short:"o"`
	Verbose    bool   `long:"verbose" short:"v"`
}

func initDocumentHTML(command *flags.Command) {
	const text = "Build the documentation as PDF"
	command.ShortDescription = translations.T.Sprintf(text)
	command.LongDescription = translations.T.Sprintf(text)

	for _, opt := range command.Options() {
		switch opt.LongName {
		case "html-template":
			opt.Description = translations.T.Sprintf("html template for the new document")
		case "markdown-template":
			opt.Description = translations.T.Sprintf("markdown template for the new document")
		case "output":
			opt.Description = translations.T.Sprintf("filename for the new document")
		case "verbose":
			opt.Description = translations.T.Sprintf("verbose output")
		case "single-page":
			opt.Description = translations.T.Sprintf("single page output")
		}
	}

}

func runDocumentHTML(command *flags.Command) {

	env := document.BuildHtmlEnvironment{
		DateFormat: environment.State.GetDocumentDateFormat(definition.Document.DateFormat),
		SourcePath: environment.State.GetDocumentPath(definition.Document.SourcePath),
		OutputPath: environment.State.GetDocumentHTMLOutputPath(definition.Document.PDF.OutputPath),
	}

	env.Templates.HTML = environment.State.GetHTMLHTMLTemplatePath(definition.Document.HTML.HTMLTemplate)
	env.Verbose = definition.Document.HTML.Verbose
	env.SinglePage = environment.State.GetHTMLSinglePageState(definition.Document.HTML.SinglePage)

	document.BuildHTML(env)

	if environment.State.HasErrorsWarningsOrMessages() {
		environment.PrintMessages()
	}

}
